@@ -184,6 +184,13 @@ Chake.nodes.each do |node|
     end
   end
 
+  desc "Preview changes when converging #{hostname}"
+  task "preview:#{hostname}" => converge_dependencies do
+    maybe_decrypt(node) do
+      node.preview
+    end
+  end
+
   desc 'apply <recipe> on #{hostname}'
   task "apply:#{hostname}", [:recipe] => [:recipe_input, :connect_common, "connect:#{hostname}"] do |_task, _args|
     maybe_decrypt(node) do
@@ -262,6 +269,9 @@ multitask bootstrap: Chake.nodes.map { |node| "bootstrap:#{node.hostname}" }
 desc 'converge all nodes (default)'
 multitask 'converge' => Chake.nodes.map { |node| "converge:#{node.hostname}" }
 
+desc 'Preview changes when converigng all nodes'
+multitask 'preview' => Chake.nodes.map { |node| "preview:#{node.hostname}" }
+
 desc 'Apply <recipe> on all nodes'
 multitask 'apply', [:recipe] => Chake.nodes.map { |node| "apply:#{node.hostname}" }
 
