@@ -1,21 +1,11 @@
 require 'shellwords'
 require 'chake/config'
 require 'chake/tmpdir'
+require 'chake/config_manager/itamae_base'
 
 module Chake
   class ConfigManager
-    class Itamae < ConfigManager
-      def converge
-        recipes = node.data['itamae']
-        return if recipes.empty?
-
-        run_itamae(*recipes)
-      end
-
-      def apply(config)
-        run_itamae(config)
-      end
-
+    class Itamae < ItamaeBase
       def needs_upload?
         false
       end
@@ -26,7 +16,7 @@ module Chake
 
       private
 
-      def run_itamae(*recipes)
+      def run_itamae(preview, *recipes)
         cmd = ['itamae']
         case node.connection
         when Chake::Connection::Ssh
@@ -44,6 +34,9 @@ module Chake
         if node.silent
           cmd << '--log-level=warn'
         end
+        if preview
+          cmd << '--dry-run'
+        end
         cmd += recipes
         node.log("$ #{cmd.join(' ')}")
         io = IO.popen(cmd, 'r', err: %i[child out])
