@@ -1,21 +1,11 @@
 require 'shellwords'
 require 'chake/config'
 require 'chake/tmpdir'
+require 'chake/config_manager/itamae_base'
 
 module Chake
   class ConfigManager
-    class ItamaeRemote < ConfigManager
-      def converge
-        recipes = node.data['itamae-remote']
-        return if recipes.empty?
-
-        run_itamae(*recipes)
-      end
-
-      def apply(config)
-        run_itamae(config)
-      end
-
+    class ItamaeRemote < ItamaeBase
       def needs_upload?
         true
       end
@@ -26,11 +16,14 @@ module Chake
 
       private
 
-      def run_itamae(*recipes)
+      def run_itamae(preview, *recipes)
         cmd = ['itamae', 'local', "--node-json=#{json_config}"]
         if node.silent
           cmd << '--log-level=warn'
         end
+        if preview
+          cmd << '--dry-run'
+        end
         cmd += recipes.map { |r| File.join(node.path, r) }
         node.run_as_root(Shellwords.join(cmd))
       end
