@@ -45,6 +45,15 @@ module Chake
 
     def_delegators :config_manager, :converge, :apply, :path, :bootstrap_steps, :needs_upload?
 
+    def preview
+      unless config_manager.respond_to?(:preview)
+        puts "I: the #{config_manager} driver does not support preview"
+        return
+      end
+
+      config_manager.preview
+    end
+
     def path
       @path ||= config_manager.path
     end
